@@ -18,21 +18,12 @@ Test to add:
 import time
 
 import pytest
-from invenio_pidstore.errors import PIDDeletedError
+from invenio_pidstore.errors import PIDDeletedError, PIDUnregistered
 from invenio_pidstore.models import PIDStatus
 from invenio_search import current_search, current_search_client
+from marshmallow.exceptions import ValidationError
 from sqlalchemy.orm.exc import NoResultFound
 
-
-@pytest.fixture()
-def input_data():
-    """Input data (as coming from the view layer)."""
-    return {
-        'metadata': {
-            'title': 'Test'
-        },
-    }
-
 #
 # Operations tests
 #
@@ -42,6 +33,8 @@ def test_create_draft(app, service, identity_simple, input_data):
     """Test draft creation of a non-existing record."""
     # Needs `app` context because of invenio_access/permissions.py#166
     draft = service.create(identity_simple, input_data)
+    draft_dict = draft.to_dict()
+
     assert draft.id
     assert draft._record.revision_id == 1
 
@@ -51,9 +44,29 @@ def test_create_draft(app, service, identity_simple, input_data):
     # Check for pid and parent pid
     assert draft['id']
     assert draft['conceptid']
-
     assert draft._record.pid.status == PIDStatus.NEW
     assert draft._record.conceptpid.status == PIDStatus.NEW
+    assert 'errors' not in draft_dict
+
+
+def test_create_empty_draft(app, service, identity_simple):
+    """Test an empty draft can be created.
+
+    Errors (missing required fields) are reported, but don't prevent creation.
+    """
+    # Needs `app` context because of invenio_access/permissions.py#166
+    input_data = {
+        "metadata": {}
+    }
+
+    draft = service.create(identity_simple, input_data)
+    draft_dict = draft.to_dict()
+
+    assert draft['id']
+    assert draft['conceptid']
+    assert draft._record.pid.status == PIDStatus.NEW
+    assert draft._record.conceptpid.status == PIDStatus.NEW
+    assert draft_dict['errors']['metadata']['title']
 
 
 def test_read_draft(app, service, identity_simple, input_data):
@@ -85,6 +98,22 @@ def test_update_draft(app, service, identity_simple, input_data):
     assert update_draft["metadata"]['title'] == edited_title
 
 
+def test_update_draft_invalid_field(app, service, identity_simple, input_data):
+    """Update with invalid field reports rather than raises errors."""
+    # Needs `app` context because of invenio_access/permissions.py#166
+    draft = service.create(identity_simple, input_data)
+    orig_title = input_data['metadata']['title']
+    edited_title = 100
+    input_data['metadata']['title'] = edited_title
+
+    updated_draft = service.update_draft(draft.id, identity_simple, input_data)
+    updated_draft_dict = updated_draft.to_dict()
+
+    assert draft.id == updated_draft.id
+    assert updated_draft["metadata"]['title'] == orig_title
+    assert updated_draft_dict["errors"]["metadata"]['title']
+
+
 def test_delete_draft(app, service, identity_simple, input_data):
     # Needs `app` context because of invenio_access/permissions.py#166
     draft = service.create(identity_simple, input_data)
@@ -141,6 +170,34 @@ def test_publish_draft(app, service, identity_simple, input_data):
         assert record[key] == value
 
 
+def test_fail_to_publish_invalid_draft(app, service, identity_simple):
+    """Publishing an incomplete draft should fail.
+
+    Note that the publish action requires a draft to be created first.
+    """
+    # Needs `app` context because of invenio_access/permissions.py#166
+    input_data = {
+        "metadata": {}
+    }
+    draft = service.create(identity_simple, input_data)
+
+    with pytest.raises(ValidationError) as e:
+        record = service.publish(draft.id, identity_simple)
+
+    exception = e.value
+    assert "metadata" not in exception.valid_data
+
+    # Draft still there
+    draft = service.read_draft(draft.id, identity_simple)
+    assert draft
+    assert draft._record.pid.status == PIDStatus.NEW
+    assert draft._record.conceptpid.status == PIDStatus.NEW
+
+    # Test no published record exists
+    with pytest.raises(PIDUnregistered) as e:
+        record = service.read(draft.id, identity_simple)
+
+
 #
 # Flow tests (Note that operations are tested above
 # therefore these tests do not assert their output)
